@@ -15,7 +15,8 @@ class Event(object):
         try:
             self.handlers.remove(handler)
         except:
-            raise ValueError("Handler is not handling this event, so cannot unhandle it.")
+            raise ValueError(
+                "Handler is not handling this event, so cannot unhandle it.")
         return self
 
     def fire(self, *args, **kargs):
